==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/monitor/run/bean/MonitorNumericValueInfo.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;

/**
 * ʹƻȽ󥯥饹Ǥ
 * 
 * @version 2.1.0
 * @since 2.0.0
 */
public class MonitorNumericValueInfo
	extends MonitorJudgementInfo
{
	private static final long serialVersionUID = -7307483294508379452L;
	
	/** Ͳ */
	protected float m_thresholdLowerLimit;
	
	/** ; */
	protected float m_thresholdUpperLimit; 
	
	
	/**
	 * 󥹥ȥ饯
	 */
	public MonitorNumericValueInfo() {
		super();
	}
	
	/**
	 * 󥹥ȥ饯
	 * 
	 * @param message
	 * @param messageId
	 * @param monitorId
	 * @param monitorTypeId
	 * @param priority
	 * @param thresholdLowerLimit
	 * @param thresholdUpperLimit
	 * @param jobRun
	 * @param jobId
	 * @param jobInhibitionFlg
	 * @param jobFailurePriority
	 */
	public MonitorNumericValueInfo(
			String message,
			String messageId,
			String monitorId,
			String monitorTypeId,
			int priority,
			float thresholdLowerLimit,
			float thresholdUpperLimit,
			int jobRun,
			String jobId,
			int jobInhibitionFlg,
			int jobFailurePriority )
	{
		setMessage(message);
		setMessageId(messageId);
		setMonitorId(monitorId);
		setMonitorTypeId(monitorTypeId);
		setPriority(priority);
		setThresholdLowerLimit(thresholdLowerLimit);
		setThresholdUpperLimit(thresholdUpperLimit);
		setJobRun(jobRun);
		setJobId(jobId);
		setJobInhibitionFlg(jobInhibitionFlg);
		setJobFailurePriority(jobFailurePriority);
	}
	
	/**
	 * 󥹥ȥ饯
	 * 
	 * @param otherData
	 */
	public MonitorNumericValueInfo( MonitorNumericValueInfo otherData )
	{
		setMessage(otherData.getMessage());
		setMessageId(otherData.getMessageId());
		setMonitorId(otherData.getMonitorId());
		setMonitorTypeId(otherData.getMonitorTypeId());
		setPriority(otherData.getPriority());
		setThresholdLowerLimit(otherData.getThresholdLowerLimit());
		setThresholdUpperLimit(otherData.getThresholdUpperLimit());
		setJobRun(otherData.getJobRun());
		setJobId(otherData.getJobId());
		setJobInhibitionFlg(otherData.getJobInhibitionFlg());
		setJobFailurePriority(otherData.getJobFailurePriority());
	}
	
	/**
	 * @return m_thresholdLowerLimit ᤷޤ
	 */
	public float getThresholdLowerLimit()
	{
		return this.m_thresholdLowerLimit;
	}
	
	/**
	 * @param thresholdLowerLimit ꤹ m_thresholdLowerLimit
	 */
	public void setThresholdLowerLimit( float thresholdLowerLimit )
	{
		this.m_thresholdLowerLimit = thresholdLowerLimit;
	}
	
	/**
	 * @return m_thresholdUpperLimit ᤷޤ
	 */
	public float getThresholdUpperLimit()
	{
		return this.m_thresholdUpperLimit;
	}
	
	/**
	 * @param thresholdUpperLimit ꤹ m_thresholdUpperLimit
	 */
	public void setThresholdUpperLimit( float thresholdUpperLimit )
	{
		this.m_thresholdUpperLimit = thresholdUpperLimit;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/monitor/run/bean/MonitorNumericValueInfo.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;

/**
 * 数値監視判定情報クラスです。
 * 
 * @version 2.1.0
 * @since 2.0.0
 */
public class MonitorNumericValueInfo
	extends MonitorJudgementInfo
{
	private static final long serialVersionUID = -7307483294508379452L;
	
	/** 閾値下限 */
	protected double m_thresholdLowerLimit;
	
	/** 閾値上限 */
	protected double m_thresholdUpperLimit; 
	
	
	/**
	 * コンストラクタ
	 */
	public MonitorNumericValueInfo() {
		super();
	}
	
	/**
	 * コンストラクタ
	 * 
	 * @param message
	 * @param messageId
	 * @param monitorId
	 * @param monitorTypeId
	 * @param priority
	 * @param thresholdLowerLimit
	 * @param thresholdUpperLimit
	 * @param jobRun
	 * @param jobId
	 * @param jobInhibitionFlg
	 * @param jobFailurePriority
	 */
	public MonitorNumericValueInfo(
			String message,
			String messageId,
			String monitorId,
			String monitorTypeId,
			int priority,
			double thresholdLowerLimit,
			double thresholdUpperLimit,
			int jobRun,
			String jobId,
			int jobInhibitionFlg,
			int jobFailurePriority )
	{
		setMessage(message);
		setMessageId(messageId);
		setMonitorId(monitorId);
		setMonitorTypeId(monitorTypeId);
		setPriority(priority);
		setThresholdLowerLimit(thresholdLowerLimit);
		setThresholdUpperLimit(thresholdUpperLimit);
		setJobRun(jobRun);
		setJobId(jobId);
		setJobInhibitionFlg(jobInhibitionFlg);
		setJobFailurePriority(jobFailurePriority);
	}
	
	/**
	 * コンストラクタ
	 * 
	 * @param otherData
	 */
	public MonitorNumericValueInfo( MonitorNumericValueInfo otherData )
	{
		setMessage(otherData.getMessage());
		setMessageId(otherData.getMessageId());
		setMonitorId(otherData.getMonitorId());
		setMonitorTypeId(otherData.getMonitorTypeId());
		setPriority(otherData.getPriority());
		setThresholdLowerLimit(otherData.getThresholdLowerLimit());
		setThresholdUpperLimit(otherData.getThresholdUpperLimit());
		setJobRun(otherData.getJobRun());
		setJobId(otherData.getJobId());
		setJobInhibitionFlg(otherData.getJobInhibitionFlg());
		setJobFailurePriority(otherData.getJobFailurePriority());
	}
	
	/**
	 * @return m_thresholdLowerLimit を戻します。
	 */
	public double getThresholdLowerLimit()
	{
		return this.m_thresholdLowerLimit;
	}
	
	/**
	 * @param thresholdLowerLimit 設定する m_thresholdLowerLimit。
	 */
	public void setThresholdLowerLimit( double thresholdLowerLimit )
	{
		this.m_thresholdLowerLimit = thresholdLowerLimit;
	}
	
	/**
	 * @return m_thresholdUpperLimit を戻します。
	 */
	public double getThresholdUpperLimit()
	{
		return this.m_thresholdUpperLimit;
	}
	
	/**
	 * @param thresholdUpperLimit 設定する m_thresholdUpperLimit。
	 */
	public void setThresholdUpperLimit( double thresholdUpperLimit )
	{
		this.m_thresholdUpperLimit = thresholdUpperLimit;
	}
}
